drop table basket;
drop table mycoupon;
drop table coupon;
drop table inventory;
drop table mypoint;
drop table p_order;
drop table qna;
drop table review;
drop table sms;
drop table stat;
drop table visitor;
drop table wishlist;
drop table member;
drop table product;
drop table category;
drop table madein;
drop table maker;

-- 회원
CREATE TABLE member(
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  NAME varchar(30) NOT NULL,
  PW varchar(30) NOT NULL,
  NICKNAME varchar(20),
  ZIPCODE varchar(7) DEFAULT '',
  ADDRESS varchar(255) DEFAULT '',
  MOBILE varchar(13) DEFAULT '',
  EMAIL varchar(50),
  AGE integer DEFAULT 0 NOT NULL,
  REGDATE date DEFAULT SYSDATE,
  LASTLOGIN date DEFAULT SYSDATE NOT NULL,
  DORMANT char(1) DEFAULT 'N' NOT NULL
);

-- 내 포인트 누적 정보
CREATE TABLE mypoint(
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  USERID number REFERENCES member(ID),
  POINT integer DEFAULT 0 NOT NULL,
  WT date DEFAULT SYSDATE
);

-- 메이커
CREATE TABLE maker (
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  NAME varchar(20) NOT NULL,
  LONGNAME varchar(50) DEFAULT ''
);

-- 원산지
CREATE TABLE madein (
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  COUNTRY varchar(20) NOT NULL,
  ENGNAME varchar(50)
);

-- 쿠폰
CREATE TABLE coupon (
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  TITLE varchar(255) NOT NULL,
  POINT integer DEFAULT 0 NOT NULL,
  STARTDATE varchar(10) DEFAULT '',
  ENDDATE varchar(10) DEFAULT ''
);

-- 내쿠폰
CREATE TABLE mycoupon(
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  USERID number REFERENCES member(ID),
  COUPONID number REFERENCES coupon(ID),
  isused char(1) NOT NULL default 'N'
);

-- 상품 카테고리
CREATE TABLE category (
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  TITLE varchar(50) NOT NULL
);

-- 상품
CREATE TABLE product (
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  NAME varchar(255) NOT NULL,
  MAKER number REFERENCES maker(ID),
  IMAGE_L varchar(255) NOT NULL,
  IMAGE_B varchar(255) DEFAULT NULL,
  IMAGE_M varchar(255) DEFAULT NULL,
  IMAGE_S varchar(255) DEFAULT NULL,
  REGDATE date default sysdate,
  MADEIN char(20),
  CATEGORY number,
  SELL char(1) DEFAULT 'N',
  PURCHASE_PRICE integer default 0 not null,
  SELL_PRICE integer default 0 not null,
  BRAND varchar(50) DEFAULT '',
  P_OPTION varchar(30),
  DESCRIPTION clob,
  LINK number
);

-- 장바구니
CREATE TABLE basket (
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  USERID number REFERENCES member(ID),
  P_CODE number REFERENCES product(ID),
  P_NUM integer DEFAULT 1,
  P_SELL_PRICE number DEFAULT 0 NOT NULL,
  P_OPTION varchar(255) DEFAULT '',
  COUPON number,
  DTDMONEY int DEFAULT 0,
  WT date DEFAULT SYSDATE
);

-- 주문
CREATE TABLE p_order(
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  USERID number REFERENCES member(ID),
  P_CODE number REFERENCES product(ID),
  P_NUM integer DEFAULT 1,
  P_SELL_PRICE number DEFAULT 0 NOT NULL,
  P_OPTION varchar(255) DEFAULT '',
  COUPON number,
  DTDMONEY integer DEFAULT 0,
  MOBILE varchar(14) not null,
  ADDRESS varchar(255),
  ZIPCODE varchar(5),
  CANCEL varchar(1) default 'N' not null,
  WT date DEFAULT SYSDATE
);

-- 찜해놓기
CREATE TABLE wishlist (
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  USERID number REFERENCES member(ID),
  P_CODE number REFERENCES product(ID),
  P_SELL_PRICE number DEFAULT 0,
  P_OPTION varchar(255) DEFAULT '',
  WT date DEFAULT SYSDATE
);

-- 재고
CREATE TABLE inventory(
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  P_CODE number REFERENCES product(ID),
  stock integer DEFAULT 0 NOT NULL
);

-- 상품 질문과 답변
CREATE TABLE qna (
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  P_CODE number REFERENCES product(ID),
  USERID number REFERENCES member(ID),
  TITLE varchar(255) NOT NULL,
  CONTENT clob NOT NULL,
  WT date default sysdate,
  SECRET varchar(1) DEFAULT 'N',
  ISDELETED char(1) NOT NULL DEFAULT 'N'  
);

-- 구매후기
CREATE TABLE review (
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  P_CODE number REFERENCES product(ID),
  USERID number REFERENCES member(ID),
  TITLE varchar(255) NOT NULL,
  CONTENT clob,
  RATING integer,
  WT date default sysdate
);

-- 매출합계기록
CREATE TABLE stat(
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
  USERID number REFERENCES member(ID),
	YM varchar(8) NOT NULL,
	buysum integer DEFAULT 0 NOT NULL
);

-- 방문자통계
CREATE TABLE visitor(
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
	USERID number,
	visit timestamp,
	ip varchar(16),
	url varchar(255)
);

-- sms 발송
CREATE TABLE sms(
  ID number GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL PRIMARY KEY,
	mobile varchar(15) not null,
	content varchar(2000) NOT NULL,
	send char(1) default 'N' NOT NULL,
  WT date default sysdate
);

COMMIT;